==> s2-data-0.22.tar.gz: s2-data-0.22/src/s2_data/assets/known_assets.py <==
KNOWN_ASSETS = [
    b"Data/Fonts/fontdebug.fnb",
    b"Data/Fonts/fontfirasans.fnb",
    b"Data/Fonts/fontmono.fnb",
    b"Data/Fonts/fontyorkten.fnb",
    b"Data/Levels/abzu.lvl",
    b"Data/Levels/Arena/dm1-1.lvl",
    b"Data/Levels/Arena/dm1-2.lvl",
    b"Data/Levels/Arena/dm1-3.lvl",
    b"Data/Levels/Arena/dm1-4.lvl",
    b"Data/Levels/Arena/dm1-5.lvl",
    b"Data/Levels/Arena/dm2-1.lvl",
    b"Data/Levels/Arena/dm2-2.lvl",
    b"Data/Levels/Arena/dm2-3.lvl",
    b"Data/Levels/Arena/dm2-4.lvl",
    b"Data/Levels/Arena/dm2-5.lvl",
    b"Data/Levels/Arena/dm3-1.lvl",
    b"Data/Levels/Arena/dm3-2.lvl",
    b"Data/Levels/Arena/dm3-3.lvl",
    b"Data/Levels/Arena/dm3-4.lvl",
    b"Data/Levels/Arena/dm3-5.lvl",
    b"Data/Levels/Arena/dm4-1.lvl",
    b"Data/Levels/Arena/dm4-2.lvl",
    b"Data/Levels/Arena/dm4-3.lvl",
    b"Data/Levels/Arena/dm4-4.lvl",
    b"Data/Levels/Arena/dm4-5.lvl",
    b"Data/Levels/Arena/dm5-1.lvl",
    b"Data/Levels/Arena/dm5-2.lvl",
    b"Data/Levels/Arena/dm5-3.lvl",
    b"Data/Levels/Arena/dm5-4.lvl",
    b"Data/Levels/Arena/dm5-5.lvl",
    b"Data/Levels/Arena/dm6-1.lvl",
    b"Data/Levels/Arena/dm6-2.lvl",
    b"Data/Levels/Arena/dm6-3.lvl",
    b"Data/Levels/Arena/dm6-4.lvl",
    b"Data/Levels/Arena/dm6-5.lvl",
    b"Data/Levels/Arena/dm7-1.lvl",
    b"Data/Levels/Arena/dm7-2.lvl",
    b"Data/Levels/Arena/dm7-3.lvl",
    b"Data/Levels/Arena/dm7-4.lvl",
    b"Data/Levels/Arena/dm7-5.lvl",
    b"Data/Levels/Arena/dm8-1.lvl",
    b"Data/Levels/Arena/dm8-2.lvl",
    b"Data/Levels/Arena/dm8-3.lvl",
    b"Data/Levels/Arena/dm8-4.lvl",
    b"Data/Levels/Arena/dm8-5.lvl",
    b"Data/Levels/Arena/dmpreview.tok",
    b"Data/Levels/babylonarea_1-1.lvl",
    b"Data/Levels/babylonarea.lvl",
    b"Data/Levels/basecamp_garden.lvl",
    b"Data/Levels/basecamp.lvl",
    b"Data/Levels/basecamp_shortcut_discovered.lvl",
    b"Data/Levels/basecamp_shortcut_undiscovered.lvl",
    b"Data/Levels/basecamp_shortcut_unlocked.lvl",
    b"Data/Levels/basecamp_surface.lvl",
    b"Data/Levels/basecamp_tutorial.lvl",
    b"Data/Levels/basecamp_tv_room_locked.lvl",
    b"Data/Levels/basecamp_tv_room_unlocked.lvl",
    b"Data/Levels/beehive.lvl",
    b"Data/Levels/blackmarket.lvl",
    b"Data/Levels/cavebossarea.lvl",
    b"Data/Levels/challenge_moon.lvl",
    b"Data/Levels/challenge_star.lvl",
    b"Data/Levels/challenge_sun.lvl",
    b"Data/Levels/cityofgold.lvl",
    b"Data/Levels/cosmicocean_babylon.lvl",
    b"Data/Levels/cosmicocean_dwelling.lvl",
    b"Data/Levels/cosmicocean_icecavesarea.lvl",
    b"Data/Levels/cosmicocean_jungle.lvl",
    b"Data/Levels/cosmicocean_sunkencity.lvl",
    b"Data/Levels/cosmicocean_temple.lvl",
    b"Data/Levels/cosmicocean_tidepool.lvl",
    b"Data/Levels/cosmicocean_volcano.lvl",
    b"Data/Levels/duat.lvl",
    b"Data/Levels/dwellingarea.lvl",
    b"Data/Levels/ending_hard.lvl",
    b"Data/Levels/eggplantarea.lvl",
    b"Data/Levels/ending.lvl",
    b"Data/Levels/generic.lvl",
    b"Data/Levels/hallofushabti.lvl",
    b"Data/Levels/hundun.lvl",
    b"Data/Levels/icecavesarea.lvl",
    b"Data/Levels/junglearea.lvl",
    b"Data/Levels/lake.lvl",
    b"Data/Levels/lakeoffire.lvl",
    b"Data/Levels/olmecarea.lvl",
    b"Data/Levels/palaceofpleasure.lvl",
    b"Data/Levels/sunkencityarea.lvl",
    b"Data/Levels/templearea.lvl",
    b"Data/Levels/testingarea.lvl",
    b"Data/Levels/tiamat.lvl",
    b"Data/Levels/tidepoolarea.lvl",
    b"Data/Levels/vladscastle.lvl",
    b"Data/Levels/volcanoarea.lvl",
    b"Data/Textures/base_eggship2.DDS",
    b"Data/Textures/base_eggship3.DDS",
    b"Data/Textures/base_eggship.DDS",
    b"Data/Textures/base_skynight.DDS",
    b"Data/Textures/base_surface2.DDS",
    b"Data/Textures/base_surface.DDS",
    b"Data/Textures/bayer8.DDS",
    b"Data/Textures/bg_babylon.DDS",
    b"Data/Textures/bg_beehive.DDS",
    b"Data/Textures/bg_cave.DDS",
    b"Data/Textures/bg_duat2.DDS",
    b"Data/Textures/bg_duat.DDS",
    b"Data/Textures/bg_eggplant.DDS",
    b"Data/Textures/bg_gold.DDS",
    b"Data/Textures/bg_ice.DDS",
    b"Data/Textures/bg_jungle.DDS",
    b"Data/Textures/bg_mothership.DDS",
    b"Data/Textures/bg_stone.DDS",
    b"Data/Textures/bg_sunken.DDS",
    b"Data/Textures/bg_temple.DDS",
    b"Data/Textures/bg_tidepool.DDS",
    b"Data/Textures/bg_vlad.DDS",
    b"Data/Textures/bg_volcano.DDS",
    b"Data/Textures/border_main.DDS",
    b"Data/Textures/char_black.DDS",
    b"Data/Textures/char_blue.DDS",
    b"Data/Textures/char_cerulean.DDS",
    b"Data/Textures/char_cinnabar.DDS",
    b"Data/Textures/char_cyan.DDS",
    b"Data/Textures/char_eggchild.DDS",
    b"Data/Textures/char_gold.DDS",
    b"Data/Textures/char_gray.DDS",
    b"Data/Textures/char_green.DDS",
    b"Data/Textures/char_hired.DDS",
    b"Data/Textures/char_iris.DDS",
    b"Data/Textures/char_khaki.DDS",
    b"Data/Textures/char_lemon.DDS",
    b"Data/Textures/char_lime.DDS",
    b"Data/Textures/char_magenta.DDS",
    b"Data/Textures/char_olive.DDS",
    b"Data/Textures/char_orange.DDS",
    b"Data/Textures/char_pink.DDS",
    b"Data/Textures/char_red.DDS",
    b"Data/Textures/char_violet.DDS",
    b"Data/Textures/char_white.DDS",
    b"Data/Textures/char_yellow.DDS",
    b"Data/Textures/coffins.DDS",
    b"Data/Textures/credits.DDS",
    b"Data/Textures/deco_babylon.DDS",
    b"Data/Textures/deco_basecamp.DDS",
    b"Data/Textures/deco_cave.DDS",
    b"Data/Textures/deco_cosmic.DDS",
    b"Data/Textures/deco_eggplant.DDS",
    b"Data/Textures/deco_extra.DDS",
    b"Data/Textures/deco_gold.DDS",
    b"Data/Textures/deco_ice.DDS",
    b"Data/Textures/deco_jungle.DDS",
    b"Data/Textures/deco_sunken.DDS",
    b"Data/Textures/deco_temple.DDS",
    b"Data/Textures/deco_tidepool.DDS",
    b"Data/Textures/deco_tutorial.DDS",
    b"Data/Textures/deco_volcano.DDS",
    b"Data/Textures/floor_babylon.DDS",
    b"Data/Textures/floor_cave.DDS",
    b"Data/Textures/floor_eggplant.DDS",
    b"Data/Textures/floor_ice.DDS",
    b"Data/Textures/floor_jungle.DDS",
    b"Data/Textures/floormisc.DDS",
    b"Data/Textures/floorstyled_babylon.DDS",
    b"Data/Textures/floorstyled_beehive.DDS",
    b"Data/Textures/floorstyled_duat.DDS",
    b"Data/Textures/floorstyled_gold_normal.DDS",
    b"Data/Textures/floorstyled_gold.DDS",
    b"Data/Textures/floorstyled_guts.DDS",
    b"Data/Textures/floorstyled_mothership.DDS",
    b"Data/Textures/floorstyled_pagoda.DDS",
    b"Data/Textures/floorstyled_palace.DDS",
    b"Data/Textures/floorstyled_stone.DDS",
    b"Data/Textures/floorstyled_sunken.DDS",
    b"Data/Textures/floorstyled_temple.DDS",
    b"Data/Textures/floorstyled_vlad.DDS",
    b"Data/Textures/floorstyled_wood.DDS",
    b"Data/Textures/floor_sunken.DDS",
    b"Data/Textures/floor_surface.DDS",
    b"Data/Textures/floor_temple.DDS",
    b"Data/Textures/floor_tidepool.DDS",
    b"Data/Textures/floor_volcano.DDS",
    b"Data/Textures/fontdebug.DDS",
    b"Data/Textures/fontfirasans.DDS",
    b"Data/Textures/fontmono.DDS",
    b"Data/Textures/fontyorkten.DDS",
    b"Data/Textures/fx_ankh.DDS",
    b"Data/Textures/fx_big.DDS",
    b"Data/Textures/fx_explosion.DDS",
    b"Data/Textures/fx_rubble.DDS",
    b"Data/Textures/fx_small2.DDS",
    b"Data/Textures/fx_small3.DDS",
    b"Data/Textures/fx_small.DDS",
    b"Data/Textures/hud_controller_buttons.DDS",
    b"Data/Textures/hud.DDS",
    b"Data/Textures/hud_text.DDS",
    b"Data/Textures/items.DDS",
    b"Data/Textures/items_ushabti.DDS",
    b"Data/Textures/journal_back.DDS",
    b"Data/Textures/journal_elements.DDS",
    b"Data/Textures/journal_entry_bg.DDS",
    b"Data/Textures/journal_entry_items.DDS",
    b"Data/Textures/journal_entry_mons_big.DDS",
    b"Data/Textures/journal_entry_mons.DDS",
    b"Data/Textures/journal_entry_people.DDS",
    b"Data/Textures/journal_entry_place.DDS",
    b"Data/Textures/journal_entry_traps.DDS",
    b"Data/Textures/journal_pageflip.DDS",
    b"Data/Textures/journal_pagetorn.DDS",
    b"Data/Textures/journal_select.DDS",
    b"Data/Textures/journal_stickers.DDS",
    b"Data/Textures/journal_story.DDS",
    b"Data/Textures/journal_top_entry.DDS",
    b"Data/Textures/journal_top_gameover.DDS",
    b"Data/Textures/journal_top_main.DDS",
    b"Data/Textures/journal_top_profile.DDS",
    b"Data/Textures/loading.DDS",
    b"Data/Textures/lut_backlayer.DDS",
    b"Data/Textures/lut_blackmarket.DDS",
    b"Data/Textures/lut_icecaves.DDS",
    b"Data/Textures/lut_original.DDS",
    b"Data/Textures/lut_vlad.DDS",
    b"Data/Textures/main_body.DDS",
    b"Data/Textures/main_dirt.DDS",
    b"Data/Textures/main_doorback.DDS",
    b"Data/Textures/main_doorframe.DDS",
    b"Data/Textures/main_door.DDS",
    b"Data/Textures/main_fore1.DDS",
    b"Data/Textures/main_fore2.DDS",
    b"Data/Textures/main_head.DDS",
    b"Data/Textures/menu_basic.DDS",
    b"Data/Textures/menu_brick1.DDS",
    b"Data/Textures/menu_brick2.DDS",
    b"Data/Textures/menu_cave1.DDS",
    b"Data/Textures/menu_cave2.DDS",
    b"Data/Textures/menu_chardoor.DDS",
    b"Data/Textures/menu_charsel.DDS",
    b"Data/Textures/menu_deathmatch2.DDS",
    b"Data/Textures/menu_deathmatch3.DDS",
    b"Data/Textures/menu_deathmatch4.DDS",
    b"Data/Textures/menu_deathmatch5.DDS",
    b"Data/Textures/menu_deathmatch6.DDS",
    b"Data/Textures/menu_deathmatch.DDS",
    b"Data/Textures/menu_disp.DDS",
    b"Data/Textures/menu_generic.DDS",
    b"Data/Textures/menu_header.DDS",
    b"Data/Textures/menu_leader.DDS",
    b"Data/Textures/menu_online.DDS",
    b"Data/Textures/menu_titlegal.DDS",
    b"Data/Textures/menu_title.DDS",
    b"Data/Textures/menu_tunnel.DDS",
    b"Data/Textures/monsters01.DDS",
    b"Data/Textures/monsters02.DDS",
    b"Data/Textures/monsters03.DDS",
    b"Data/Textures/monstersbasic01.DDS",
    b"Data/Textures/monstersbasic02.DDS",
    b"Data/Textures/monstersbasic03.DDS",
    b"Data/Textures/monstersbig01.DDS",
    b"Data/Textures/monstersbig02.DDS",
    b"Data/Textures/monstersbig03.DDS",
    b"Data/Textures/monstersbig04.DDS",
    b"Data/Textures/monstersbig05.DDS",
    b"Data/Textures/monstersbig06.DDS",
    b"Data/Textures/monsters_ghost.DDS",
    b"Data/Textures/monsters_hundun.DDS",
    b"Data/Textures/monsters_olmec.DDS",
    b"Data/Textures/monsters_osiris.DDS",
    b"Data/Textures/monsters_pets.DDS",
    b"Data/Textures/monsters_tiamat.DDS",
    b"Data/Textures/monsters_yama.DDS",
    b"Data/Textures/mounts.DDS",
    b"Data/Textures/noise0.DDS",
    b"Data/Textures/noise1.DDS",
    b"Data/Textures/OldTextures/ai.DDS",
    b"Data/Textures/saving.DDS",
    b"Data/Textures/shadows.DDS",
    b"Data/Textures/shine.DDS",
    b"Data/Textures/splash0.DDS",
    b"Data/Textures/splash1.DDS",
    b"Data/Textures/splash2.DDS",
    b"shaders.hlsl",
    b"soundbank.bank",
    b"soundbank.strings.bank",
    b"strings00.str",
    b"strings01.str",
    b"strings02.str",
    b"strings03.str",
    b"strings04.str",
    b"strings05.str",
    b"strings06.str",
    b"strings07.str",
    b"strings08.str",
]

IMAGES_DONT_CONVERT = set([
    b"Data/Textures/bayer8.DDS",
    b"Data/Textures/fontdebug.DDS",
    b"Data/Textures/fontfirasans.DDS",
    b"Data/Textures/fontmono.DDS",
    b"Data/Textures/fontyorkten.DDS",
])

==> s2-data-0.23.tar.gz: s2-data-0.23/src/s2_data/assets/known_assets.py <==
KNOWN_ASSETS = [
    b"Data/Fonts/fontdebug.fnb",
    b"Data/Fonts/fontfirasans.fnb",
    b"Data/Fonts/fontmono.fnb",
    b"Data/Fonts/fontnewrodin.fnb",
    b"Data/Fonts/fontrodincattleya.fnb",
    b"Data/Fonts/fontyorkten.fnb",
    b"Data/Levels/abzu.lvl",
    b"Data/Levels/Arena/dm1-1.lvl",
    b"Data/Levels/Arena/dm1-2.lvl",
    b"Data/Levels/Arena/dm1-3.lvl",
    b"Data/Levels/Arena/dm1-4.lvl",
    b"Data/Levels/Arena/dm1-5.lvl",
    b"Data/Levels/Arena/dm2-1.lvl",
    b"Data/Levels/Arena/dm2-2.lvl",
    b"Data/Levels/Arena/dm2-3.lvl",
    b"Data/Levels/Arena/dm2-4.lvl",
    b"Data/Levels/Arena/dm2-5.lvl",
    b"Data/Levels/Arena/dm3-1.lvl",
    b"Data/Levels/Arena/dm3-2.lvl",
    b"Data/Levels/Arena/dm3-3.lvl",
    b"Data/Levels/Arena/dm3-4.lvl",
    b"Data/Levels/Arena/dm3-5.lvl",
    b"Data/Levels/Arena/dm4-1.lvl",
    b"Data/Levels/Arena/dm4-2.lvl",
    b"Data/Levels/Arena/dm4-3.lvl",
    b"Data/Levels/Arena/dm4-4.lvl",
    b"Data/Levels/Arena/dm4-5.lvl",
    b"Data/Levels/Arena/dm5-1.lvl",
    b"Data/Levels/Arena/dm5-2.lvl",
    b"Data/Levels/Arena/dm5-3.lvl",
    b"Data/Levels/Arena/dm5-4.lvl",
    b"Data/Levels/Arena/dm5-5.lvl",
    b"Data/Levels/Arena/dm6-1.lvl",
    b"Data/Levels/Arena/dm6-2.lvl",
    b"Data/Levels/Arena/dm6-3.lvl",
    b"Data/Levels/Arena/dm6-4.lvl",
    b"Data/Levels/Arena/dm6-5.lvl",
    b"Data/Levels/Arena/dm7-1.lvl",
    b"Data/Levels/Arena/dm7-2.lvl",
    b"Data/Levels/Arena/dm7-3.lvl",
    b"Data/Levels/Arena/dm7-4.lvl",
    b"Data/Levels/Arena/dm7-5.lvl",
    b"Data/Levels/Arena/dm8-1.lvl",
    b"Data/Levels/Arena/dm8-2.lvl",
    b"Data/Levels/Arena/dm8-3.lvl",
    b"Data/Levels/Arena/dm8-4.lvl",
    b"Data/Levels/Arena/dm8-5.lvl",
    b"Data/Levels/Arena/dmpreview.tok",
    b"Data/Levels/babylonarea_1-1.lvl",
    b"Data/Levels/babylonarea.lvl",
    b"Data/Levels/basecamp_garden.lvl",
    b"Data/Levels/basecamp.lvl",
    b"Data/Levels/basecamp_shortcut_discovered.lvl",
    b"Data/Levels/basecamp_shortcut_undiscovered.lvl",
    b"Data/Levels/basecamp_shortcut_unlocked.lvl",
    b"Data/Levels/basecamp_surface.lvl",
    b"Data/Levels/basecamp_tutorial.lvl",
    b"Data/Levels/basecamp_tv_room_locked.lvl",
    b"Data/Levels/basecamp_tv_room_unlocked.lvl",
    b"Data/Levels/beehive.lvl",
    b"Data/Levels/blackmarket.lvl",
    b"Data/Levels/cavebossarea.lvl",
    b"Data/Levels/challenge_moon.lvl",
    b"Data/Levels/challenge_star.lvl",
    b"Data/Levels/challenge_sun.lvl",
    b"Data/Levels/cityofgold.lvl",
    b"Data/Levels/cosmicocean_babylon.lvl",
    b"Data/Levels/cosmicocean_dwelling.lvl",
    b"Data/Levels/cosmicocean_icecavesarea.lvl",
    b"Data/Levels/cosmicocean_jungle.lvl",
    b"Data/Levels/cosmicocean_sunkencity.lvl",
    b"Data/Levels/cosmicocean_temple.lvl",
    b"Data/Levels/cosmicocean_tidepool.lvl",
    b"Data/Levels/cosmicocean_volcano.lvl",
    b"Data/Levels/duat.lvl",
    b"Data/Levels/dwellingarea.lvl",
    b"Data/Levels/ending_hard.lvl",
    b"Data/Levels/eggplantarea.lvl",
    b"Data/Levels/ending.lvl",
    b"Data/Levels/generic.lvl",
    b"Data/Levels/hallofushabti.lvl",
    b"Data/Levels/hundun.lvl",
    b"Data/Levels/icecavesarea.lvl",
    b"Data/Levels/junglearea.lvl",
    b"Data/Levels/lake.lvl",
    b"Data/Levels/lakeoffire.lvl",
    b"Data/Levels/olmecarea.lvl",
    b"Data/Levels/palaceofpleasure.lvl",
    b"Data/Levels/sunkencityarea.lvl",
    b"Data/Levels/templearea.lvl",
    b"Data/Levels/testingarea.lvl",
    b"Data/Levels/tiamat.lvl",
    b"Data/Levels/tidepoolarea.lvl",
    b"Data/Levels/vladscastle.lvl",
    b"Data/Levels/volcanoarea.lvl",
    b"Data/Textures/base_eggship2.DDS",
    b"Data/Textures/base_eggship3.DDS",
    b"Data/Textures/base_eggship.DDS",
    b"Data/Textures/base_skynight.DDS",
    b"Data/Textures/base_surface2.DDS",
    b"Data/Textures/base_surface.DDS",
    b"Data/Textures/bayer8.DDS",
    b"Data/Textures/bg_babylon.DDS",
    b"Data/Textures/bg_beehive.DDS",
    b"Data/Textures/bg_cave.DDS",
    b"Data/Textures/bg_duat2.DDS",
    b"Data/Textures/bg_duat.DDS",
    b"Data/Textures/bg_eggplant.DDS",
    b"Data/Textures/bg_gold.DDS",
    b"Data/Textures/bg_ice.DDS",
    b"Data/Textures/bg_jungle.DDS",
    b"Data/Textures/bg_mothership.DDS",
    b"Data/Textures/bg_stone.DDS",
    b"Data/Textures/bg_sunken.DDS",
    b"Data/Textures/bg_temple.DDS",
    b"Data/Textures/bg_tidepool.DDS",
    b"Data/Textures/bg_vlad.DDS",
    b"Data/Textures/bg_volcano.DDS",
    b"Data/Textures/border_main.DDS",
    b"Data/Textures/char_black.DDS",
    b"Data/Textures/char_blue.DDS",
    b"Data/Textures/char_cerulean.DDS",
    b"Data/Textures/char_cinnabar.DDS",
    b"Data/Textures/char_cyan.DDS",
    b"Data/Textures/char_eggchild.DDS",
    b"Data/Textures/char_gold.DDS",
    b"Data/Textures/char_gray.DDS",
    b"Data/Textures/char_green.DDS",
    b"Data/Textures/char_hired.DDS",
    b"Data/Textures/char_iris.DDS",
    b"Data/Textures/char_khaki.DDS",
    b"Data/Textures/char_lemon.DDS",
    b"Data/Textures/char_lime.DDS",
    b"Data/Textures/char_magenta.DDS",
    b"Data/Textures/char_olive.DDS",
    b"Data/Textures/char_orange.DDS",
    b"Data/Textures/char_pink.DDS",
    b"Data/Textures/char_red.DDS",
    b"Data/Textures/char_violet.DDS",
    b"Data/Textures/char_white.DDS",
    b"Data/Textures/char_yellow.DDS",
    b"Data/Textures/coffins.DDS",
    b"Data/Textures/credits.DDS",
    b"Data/Textures/deco_babylon.DDS",
    b"Data/Textures/deco_basecamp.DDS",
    b"Data/Textures/deco_cave.DDS",
    b"Data/Textures/deco_cosmic.DDS",
    b"Data/Textures/deco_eggplant.DDS",
    b"Data/Textures/deco_extra.DDS",
    b"Data/Textures/deco_gold.DDS",
    b"Data/Textures/deco_ice.DDS",
    b"Data/Textures/deco_jungle.DDS",
    b"Data/Textures/deco_sunken.DDS",
    b"Data/Textures/deco_temple.DDS",
    b"Data/Textures/deco_tidepool.DDS",
    b"Data/Textures/deco_tutorial.DDS",
    b"Data/Textures/deco_volcano.DDS",
    b"Data/Textures/floor_babylon.DDS",
    b"Data/Textures/floor_cave.DDS",
    b"Data/Textures/floor_eggplant.DDS",
    b"Data/Textures/floor_ice.DDS",
    b"Data/Textures/floor_jungle.DDS",
    b"Data/Textures/floormisc.DDS",
    b"Data/Textures/floorstyled_babylon.DDS",
    b"Data/Textures/floorstyled_beehive.DDS",
    b"Data/Textures/floorstyled_duat.DDS",
    b"Data/Textures/floorstyled_gold_normal.DDS",
    b"Data/Textures/floorstyled_gold.DDS",
    b"Data/Textures/floorstyled_guts.DDS",
    b"Data/Textures/floorstyled_mothership.DDS",
    b"Data/Textures/floorstyled_pagoda.DDS",
    b"Data/Textures/floorstyled_palace.DDS",
    b"Data/Textures/floorstyled_stone.DDS",
    b"Data/Textures/floorstyled_sunken.DDS",
    b"Data/Textures/floorstyled_temple.DDS",
    b"Data/Textures/floorstyled_vlad.DDS",
    b"Data/Textures/floorstyled_wood.DDS",
    b"Data/Textures/floor_sunken.DDS",
    b"Data/Textures/floor_surface.DDS",
    b"Data/Textures/floor_temple.DDS",
    b"Data/Textures/floor_tidepool.DDS",
    b"Data/Textures/floor_volcano.DDS",
    b"Data/Textures/fontdebug.DDS",
    b"Data/Textures/fontfirasans.DDS",
    b"Data/Textures/fontmono.DDS",
    b"Data/Textures/fontnewrodin.DDS",
    b"Data/Textures/fontrodincattleya.DDS",
    b"Data/Textures/fontyorkten.DDS",
    b"Data/Textures/fx_ankh.DDS",
    b"Data/Textures/fx_big.DDS",
    b"Data/Textures/fx_explosion.DDS",
    b"Data/Textures/fx_rubble.DDS",
    b"Data/Textures/fx_small2.DDS",
    b"Data/Textures/fx_small3.DDS",
    b"Data/Textures/fx_small.DDS",
    b"Data/Textures/hud_controller_buttons.DDS",
    b"Data/Textures/hud.DDS",
    b"Data/Textures/hud_text.DDS",
    b"Data/Textures/items.DDS",
    b"Data/Textures/items_ushabti.DDS",
    b"Data/Textures/journal_back.DDS",
    b"Data/Textures/journal_elements.DDS",
    b"Data/Textures/journal_entry_bg.DDS",
    b"Data/Textures/journal_entry_items.DDS",
    b"Data/Textures/journal_entry_mons_big.DDS",
    b"Data/Textures/journal_entry_mons.DDS",
    b"Data/Textures/journal_entry_people.DDS",
    b"Data/Textures/journal_entry_place.DDS",
    b"Data/Textures/journal_entry_traps.DDS",
    b"Data/Textures/journal_pageflip.DDS",
    b"Data/Textures/journal_pagetorn.DDS",
    b"Data/Textures/journal_select.DDS",
    b"Data/Textures/journal_stickers.DDS",
    b"Data/Textures/journal_story.DDS",
    b"Data/Textures/journal_top_entry.DDS",
    b"Data/Textures/journal_top_gameover.DDS",
    b"Data/Textures/journal_top_main.DDS",
    b"Data/Textures/journal_top_profile.DDS",
    b"Data/Textures/loading.DDS",
    b"Data/Textures/lut_backlayer.DDS",
    b"Data/Textures/lut_blackmarket.DDS",
    b"Data/Textures/lut_icecaves.DDS",
    b"Data/Textures/lut_original.DDS",
    b"Data/Textures/lut_vlad.DDS",
    b"Data/Textures/main_body.DDS",
    b"Data/Textures/main_dirt.DDS",
    b"Data/Textures/main_doorback.DDS",
    b"Data/Textures/main_doorframe.DDS",
    b"Data/Textures/main_door.DDS",
    b"Data/Textures/main_fore1.DDS",
    b"Data/Textures/main_fore2.DDS",
    b"Data/Textures/main_head.DDS",
    b"Data/Textures/menu_basic.DDS",
    b"Data/Textures/menu_brick1.DDS",
    b"Data/Textures/menu_brick2.DDS",
    b"Data/Textures/menu_cave1.DDS",
    b"Data/Textures/menu_cave2.DDS",
    b"Data/Textures/menu_chardoor.DDS",
    b"Data/Textures/menu_charsel.DDS",
    b"Data/Textures/menu_deathmatch2.DDS",
    b"Data/Textures/menu_deathmatch3.DDS",
    b"Data/Textures/menu_deathmatch4.DDS",
    b"Data/Textures/menu_deathmatch5.DDS",
    b"Data/Textures/menu_deathmatch6.DDS",
    b"Data/Textures/menu_deathmatch.DDS",
    b"Data/Textures/menu_disp.DDS",
    b"Data/Textures/menu_generic.DDS",
    b"Data/Textures/menu_header.DDS",
    b"Data/Textures/menu_leader.DDS",
    b"Data/Textures/menu_online.DDS",
    b"Data/Textures/menu_titlegal.DDS",
    b"Data/Textures/menu_title.DDS",
    b"Data/Textures/menu_tunnel.DDS",
    b"Data/Textures/monsters01.DDS",
    b"Data/Textures/monsters02.DDS",
    b"Data/Textures/monsters03.DDS",
    b"Data/Textures/monstersbasic01.DDS",
    b"Data/Textures/monstersbasic02.DDS",
    b"Data/Textures/monstersbasic03.DDS",
    b"Data/Textures/monstersbig01.DDS",
    b"Data/Textures/monstersbig02.DDS",
    b"Data/Textures/monstersbig03.DDS",
    b"Data/Textures/monstersbig04.DDS",
    b"Data/Textures/monstersbig05.DDS",
    b"Data/Textures/monstersbig06.DDS",
    b"Data/Textures/monsters_ghost.DDS",
    b"Data/Textures/monsters_hundun.DDS",
    b"Data/Textures/monsters_olmec.DDS",
    b"Data/Textures/monsters_osiris.DDS",
    b"Data/Textures/monsters_pets.DDS",
    b"Data/Textures/monsters_tiamat.DDS",
    b"Data/Textures/monsters_yama.DDS",
    b"Data/Textures/mounts.DDS",
    b"Data/Textures/noise0.DDS",
    b"Data/Textures/noise1.DDS",
    b"Data/Textures/OldTextures/ai.DDS",
    b"Data/Textures/saving.DDS",
    b"Data/Textures/shadows.DDS",
    b"Data/Textures/shine.DDS",
    b"Data/Textures/splash0.DDS",
    b"Data/Textures/splash1.DDS",
    b"Data/Textures/splash2.DDS",
    b"shaders.hlsl",
    b"soundbank.bank",
    b"soundbank.strings.bank",
    b"strings00.str",
    b"strings01.str",
    b"strings02.str",
    b"strings03.str",
    b"strings04.str",
    b"strings05.str",
    b"strings06.str",
    b"strings07.str",
    b"strings08.str",
]

IMAGES_DONT_CONVERT = set([
    b"Data/Textures/bayer8.DDS",
    b"Data/Textures/fontdebug.DDS",
    b"Data/Textures/fontfirasans.DDS",
    b"Data/Textures/fontmono.DDS",
    b"Data/Textures/fontnewrodin.DDS",
    b"Data/Textures/fontrodincattleya.DDS",
    b"Data/Textures/fontyorkten.DDS",
])
